emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master b0f2065: ; Spelling fixes


From: Paul Eggert
Subject: master b0f2065: ; Spelling fixes
Date: Tue, 10 Dec 2019 23:05:58 -0500 (EST)

branch: master
commit b0f20651e3cbb8a66f11ffae4c18634019c20cd4
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    ; Spelling fixes
---
 ChangeLog.2                              |  2 +-
 ChangeLog.3                              |  6 +++---
 admin/nt/dist-build/build-dep-zips.py    |  2 +-
 doc/lispref/display.texi                 |  8 ++++----
 doc/lispref/searching.texi               |  4 ++--
 doc/lispref/windows.texi                 |  2 +-
 doc/misc/dired-x.texi                    |  2 +-
 doc/misc/org.texi                        |  4 ++--
 etc/NEWS                                 |  4 ++--
 etc/ORG-NEWS                             |  2 +-
 lisp/ChangeLog.7                         |  6 +++---
 lisp/auth-source-pass.el                 |  2 +-
 lisp/button.el                           |  2 +-
 lisp/cedet/ChangeLog.1                   |  2 +-
 lisp/gnus/gnus-cus.el                    |  2 +-
 lisp/gnus/nnimap.el                      |  2 +-
 lisp/icomplete.el                        |  2 +-
 lisp/net/newst-backend.el                |  2 +-
 lisp/org/org-attach.el                   |  4 ++--
 lisp/org/org.el                          |  4 ++--
 lisp/progmodes/cc-langs.el               |  2 +-
 lisp/progmodes/flymake.el                |  2 +-
 lisp/progmodes/hideshow.el               |  8 ++++----
 lisp/progmodes/python.el                 |  4 ++--
 lisp/so-long.el                          | 24 ++++++++++++------------
 lisp/subr.el                             |  2 +-
 lisp/thingatpt.el                        |  2 +-
 src/hbfont.c                             |  6 +++---
 src/window.c                             |  2 +-
 src/xdisp.c                              |  4 ++--
 test/lisp/abbrev-tests.el                |  2 +-
 test/lisp/cedet/semantic-utest-ia.el     |  2 +-
 test/lisp/cedet/srecode-utest-getset.el  |  1 -
 test/lisp/emacs-lisp/cl-macs-tests.el    |  4 ++--
 test/lisp/emacs-lisp/regexp-opt-tests.el |  2 +-
 test/lisp/vc/log-edit-tests.el           | 21 ++++++++++-----------
 test/manual/cedet/tests/test-fmt.cpp     | 10 +++++-----
 test/manual/cedet/tests/test.srt         |  2 +-
 test/manual/etags/cp-src/functions.cpp   |  6 +++---
 test/src/buffer-tests.el                 |  6 +++---
 test/src/fns-tests.el                    |  8 ++++----
 41 files changed, 91 insertions(+), 93 deletions(-)

diff --git a/ChangeLog.2 b/ChangeLog.2
index 453889d..c713d8a 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -15300,7 +15300,7 @@
 
        * lisp/progmodes/cc-langs.el (c++-template-syntax-table)
        (c-no-parens-syntax-table): Add extra "(eval ..)"s around "'(lambda ..)"
-       forms to remove the superflous quotes.
+       forms to remove the superfluous quotes.
 
 2015-11-24  Eli Zaretskii  <address@hidden>
 
diff --git a/ChangeLog.3 b/ChangeLog.3
index 43c7e23..27df42c 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -16432,7 +16432,7 @@
        Loading flymake-elisp.el doesn't setup flymake-mode to turn on
        automatically, but it affects emacs-lisp-mode-hook so that
        flymake-diagnostic-functions is setup with a suitable buffer-local
-       value.  The variable flymake-diagnostic-funtions in every live
+       value.  The variable flymake-diagnostic-functions in every live
        emacs-lisp-mode buffer is also adjusted.
 
        * lisp/progmodes/flymake.el (top): Require flymake-elisp.
@@ -66449,8 +66449,8 @@
        (verilog-modi-cache-results, verilog-save-buffer-state)
        (verilog-save-font-no-change-functions): When internally suppressing 
change
        functions, use `inhibit-modification-hooks' and call
-       `after-change-funtions' to more nicely work with user hooks.  Reported 
by
-       Stefan Monnier.
+       `after-change-functions' to more nicely work with user hooks.
+       Reported by Stefan Monnier.
 
        (verilog-auto, verilog-delete-auto, verilog-delete-auto-buffer):
        Create `verilog-delete-auto-buffer' to avoid double-calling
diff --git a/admin/nt/dist-build/build-dep-zips.py 
b/admin/nt/dist-build/build-dep-zips.py
index 5698f51..b538d85 100755
--- a/admin/nt/dist-build/build-dep-zips.py
+++ b/admin/nt/dist-build/build-dep-zips.py
@@ -78,7 +78,7 @@ def immediate_deps(pkg):
     ## Split into dependencies
     dependencies = dependencies.strip().split(" ")
 
-    ## Remove > signs TODO can we get any other punctation here?
+    ## Remove > signs TODO can we get any other punctuation here?
     dependencies = [d.split(">")[0] for d in dependencies if d]
     dependencies = [d for d in dependencies if not d == "None"]
 
diff --git a/doc/lispref/display.texi b/doc/lispref/display.texi
index 7f77d11..0603272 100644
--- a/doc/lispref/display.texi
+++ b/doc/lispref/display.texi
@@ -5917,7 +5917,7 @@ Draw vertical lines.
 @deffn Command curveto coordinate-sets
 Using the first element in @var{coordinate-sets}, draw a cubic Bézier
 curve from the current point.  If there are multiple coordinate sets,
-draw a polybézier.  Each coordinate set is a list of the form
+draw a polybezier.  Each coordinate set is a list of the form
 @code{(@var{x1} @var{y1} @var{x2} @var{y2} @var{x} @var{y})}, where
 @w{(@var{x}, @var{y})} is the curve’s end point.  @w{(@var{x1},
 @var{y1})} and @w{(@var{x2}, @var{y2})} are control points at the
@@ -5934,7 +5934,7 @@ beginning and at the end, respectively.
 @deffn Command smooth-curveto coordinate-sets
 Using the first element in @var{coordinate-sets}, draw a cubic Bézier
 curve from the current point.  If there are multiple coordinate sets,
-draw a polybézier.  Each coordinate set is a list of the form
+draw a polybezier.  Each coordinate set is a list of the form
 @code{(@var{x2} @var{y2} @var{x} @var{y})}, where @w{(@var{x},
 @var{y})} is the curve’s end point and @w{(@var{x2}, @var{y2})} is the
 corresponding control point.  The first control point is the
@@ -5954,7 +5954,7 @@ coincides with the current point.
 @deffn Command quadratic-bezier-curveto coordinate-sets
 Using the first element in @var{coordinate-sets}, draw a quadratic
 Bézier curve from the current point.  If there are multiple coordinate
-sets, draw a polybézier.  Each coordinate set is a list of the form
+sets, draw a polybezier.  Each coordinate set is a list of the form
 @code{(@var{x1} @var{y1} @var{x} @var{y})}, where @w{(@var{x},
 @var{y})} is the curve’s end point and @w{(@var{x1}, @var{y1})} is the
 control point.
@@ -5972,7 +5972,7 @@ control point.
 @deffn Command smooth-quadratic-bezier-curveto coordinate-sets
 Using the first element in @var{coordinate-sets}, draw a quadratic
 Bézier curve from the current point.  If there are multiple coordinate
-sets, draw a polybézier.  Each coordinate set is a list of the form
+sets, draw a polybezier.  Each coordinate set is a list of the form
 @code{(@var{x} @var{y})}, where @w{(@var{x}, @var{y})} is the curve’s
 end point.  The control point is the reflection of the control point
 of the previous command relative to the current point, if that command
diff --git a/doc/lispref/searching.texi b/doc/lispref/searching.texi
index 5bf3c5b..bf18f80 100644
--- a/doc/lispref/searching.texi
+++ b/doc/lispref/searching.texi
@@ -1551,7 +1551,7 @@ notation, @pxref{Extending Rx}.
 @subsubsection Defining new @code{rx} forms
 
 The @code{rx} notation can be extended by defining new symbols and
-parametrised forms in terms of other @code{rx} expressions.  This is
+parameterized forms in terms of other @code{rx} expressions.  This is
 handy for sharing parts between several regexps, and for making
 complex ones easier to build and understand by putting them together
 from smaller pieces.
@@ -1608,7 +1608,7 @@ defined as a plain symbol to be replaced with 
@var{rx-form}.  Example:
 @end example
 
 If @var{arglist} is present, it must be a list of zero or more
-argument names, and @var{name} is then defined as a parametrised form.
+argument names, and @var{name} is then defined as a parameterized form.
 When used in an @code{rx} expression as @code{(@var{name} @var{arg}@dots{})},
 each @var{arg} will replace the corresponding argument name inside
 @var{rx-form}.
diff --git a/doc/lispref/windows.texi b/doc/lispref/windows.texi
index fdba259..9ddd69a 100644
--- a/doc/lispref/windows.texi
+++ b/doc/lispref/windows.texi
@@ -2874,7 +2874,7 @@ Ordering}).
 A major client of this is @code{display-buffer-reuse-window}, but all
 other action functions that try to reuse a window are affected as
 well.  @code{display-buffer-in-previous-window} consults it when
-searching for a window that previosuly displayed the buffer on another
+searching for a window that previously displayed the buffer on another
 frame.
 
 @vindex inhibit-switch-frame@r{, a buffer display action alist entry}
diff --git a/doc/misc/dired-x.texi b/doc/misc/dired-x.texi
index f6f1a3c..2973dcc5 100644
--- a/doc/misc/dired-x.texi
+++ b/doc/misc/dired-x.texi
@@ -376,7 +376,7 @@ case-insensitive.
 @defvar dired-omit-localp
 This variable determines the @var{localp} argument
 @code{dired-omit-expunge} passes to @code{dired-get-filename}.  If it
-is @code{no-dir}, teh default, omitting is much faster, but you can
+is @code{no-dir}, the default, omitting is much faster, but you can
 only match against the non-directory part of the file name.  Set it to
 @code{nil} if you need to match the whole file name or @code{t} to
 match the file name relative to the buffer's top-level directory.
diff --git a/doc/misc/org.texi b/doc/misc/org.texi
index 7866fcf..4d4ca40 100644
--- a/doc/misc/org.texi
+++ b/doc/misc/org.texi
@@ -8641,7 +8641,7 @@ image @samp{1.jpg}, since the link is inside a 
sub-heading to @samp{Chapter
 
 Inheritance works the same way for both @samp{ID} and @samp{DIR} property.  If
 both properties are defined on the same headline then @samp{DIR} takes
-precedance.  This is also true if inheritance is enabled.  If @samp{DIR}
+precedence.  This is also true if inheritance is enabled.  If @samp{DIR}
 is inherited from a parent node in the outline, that property still
 takes precedence over an @samp{ID} property defined on the node itself.
 
@@ -21389,7 +21389,7 @@ Before updating a dynamic block, Org removes content 
between the
 previous content of the dynamic block becomes erased from the buffer
 and appended to the plist under @code{:content}.
 
-The syntax for naming a writer function with a dynamic block labelled
+The syntax for naming a writer function with a dynamic block labeled
 @samp{myblock} is: @code{org-dblock-write:myblock}.
 
 The following is an example of a dynamic block and a block writer function
diff --git a/etc/NEWS b/etc/NEWS
index 69b51b7..7602a2e 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -722,7 +722,7 @@ You can use this new user option to control indentation of 
arguments of
 
 ** byte compiler
 *** 'byte-compile-dynamic' is now obsolete.
-This is because on the one hand it suffers from various misbehaviors in corner
+This is because on the one hand it suffers from misbehavior in corner
 cases that have plagued it for years, and on the other experiments indicated
 that it doesn't bring any measurable benefit.
 
@@ -1237,7 +1237,7 @@ early init file.
 A new function has been added which allows users to filter the
 packages list by name: 'package-menu-filter-by-name'.  By default, it
 is bound to '/ n'.  Additionally, the function
-'package-menu-fiter-by-keyword' has been renamed from
+'package-menu-filter-by-keyword' has been renamed from
 'package-menu-filter'.  Its keybinding has also been changed to '/ k'
 (from 'f').  To clear any of the two filters, the user can now call
 the 'package-menu-clear-filter' function, bound to '/ /' by default.
diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 4ce8e9b..6f7227b 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -311,7 +311,7 @@ matches the same structures than 'latex but it calls
 org-src-font-lock-fontify-block instead, thus bringing about full
 LaTeX font locking.
 
-*** ~org-clone-subtree-with-time-shift~ learnt to shift backward in time
+*** ~org-clone-subtree-with-time-shift~ learned to shift backward in time
 
 =<C-c C-x c>= (~org-clone-subtree-with-time-shift~) now takes a
 negative value as a valid repeater to shift time stamps in backward
diff --git a/lisp/ChangeLog.7 b/lisp/ChangeLog.7
index 2fe98e8..2c2aabd 100644
--- a/lisp/ChangeLog.7
+++ b/lisp/ChangeLog.7
@@ -17104,8 +17104,8 @@
        the rewrite of `hs-inside-comment-p'.
        (hs-inside-comment-p): Rewritten from scratch.  Semantics changed
        when returning non-nil.  We can be inside a comment, but that
-       comment might not be hidable (the car of the return value should
-       be non-nil to be hidable).
+       comment might not be hideable (the car of the return value should
+       be non-nil to be hideable).
        (hs-grok-mode-type): Rewrite to be more understandable.
        `hs-c-end-regexp' does not exist any more.
        Initialize `hs-c-start-regexp' from the alist if specified there.
@@ -17117,7 +17117,7 @@
        block, go to their end and look there for the overlays.
        (java-hs-adjust-block-beginning): New function.
        (hs-hide-all): Hide a comment block only if `hs-inside-comment-p'
-       says is hidable.
+       says is hideable.
        (hs-hide-block): Simplify.  Handle properly the result of
        `hs-inside-comment-p'.
        (hs-show-block): Likewise.
diff --git a/lisp/auth-source-pass.el b/lisp/auth-source-pass.el
index 45d5a6c..7201a2d 100644
--- a/lisp/auth-source-pass.el
+++ b/lisp/auth-source-pass.el
@@ -292,7 +292,7 @@ components, from longest to shortest."
 (defun auth-source-pass--name-port-user-suffixes (name user port)
   "Return a list of possible path suffixes for NAME, USER, & PORT.
 
-The resulting list is ordered from most specifc to least
+The resulting list is ordered from most specific to least
 specific, with paths matching all of NAME, USER, & PORT first,
 then NAME & USER, then NAME & PORT, then just NAME."
   (seq-mapcat
diff --git a/lisp/button.el b/lisp/button.el
index ac6af0b..d5aaf1b 100644
--- a/lisp/button.el
+++ b/lisp/button.el
@@ -243,7 +243,7 @@ overlay, a buffer position, or (for buttons in the 
mode-line or
 header-line) a string.
 
 If BUTTON has a `button-data' value, call the function with this
-value instad of BUTTON.
+value instead of BUTTON.
 
 This function only works when BUTTON is in the current buffer."
   (let ((action (or (and use-mouse-action (button-get button 'mouse-action))
diff --git a/lisp/cedet/ChangeLog.1 b/lisp/cedet/ChangeLog.1
index 1d34219..cf8d6c4 100644
--- a/lisp/cedet/ChangeLog.1
+++ b/lisp/cedet/ChangeLog.1
@@ -453,7 +453,7 @@
 
        * semantic/ctxt.el (semantic-get-local-variables-default):
        Also try to parse local variables for buffers which are currently
-       marked as unparseable.  Otherwise, it is often impossible to
+       marked as unparsable.  Otherwise, it is often impossible to
        complete local variables.
 
        * semantic/scope.el (semantic-analyze-scoped-types-default): If we
diff --git a/lisp/gnus/gnus-cus.el b/lisp/gnus/gnus-cus.el
index 5291d1d..57e7f7c 100644
--- a/lisp/gnus/gnus-cus.el
+++ b/lisp/gnus/gnus-cus.el
@@ -257,7 +257,7 @@ Server-assigned value attached to IMAP groups, used to 
maintain consistency.")
     (modseq (choice :tag "modseq"
                    (const :tag "None" nil)
                    (string :tag "Sequence number"))
-           "Modification seqence number")
+           "Modification sequence number")
     (active (cons :tag "active" (integer :tag "min") (integer :tag "max"))
            "active")
     (permanent-flags (repeat :tag "Permanent Flags" (symbol :tag "Flag"))
diff --git a/lisp/gnus/nnimap.el b/lisp/gnus/nnimap.el
index bbbca8f..f02c2e5 100644
--- a/lisp/gnus/nnimap.el
+++ b/lisp/gnus/nnimap.el
@@ -233,7 +233,7 @@ textual parts.")
     'headers))
 
 (defun nnimap-transform-headers ()
-  "Transform server's FETCH response into parseable headers."
+  "Transform server's FETCH response into parsable headers."
   (goto-char (point-min))
   (let (seen-articles article lines size string labels)
     (cl-block nil
diff --git a/lisp/icomplete.el b/lisp/icomplete.el
index 16167ea..cd20064 100644
--- a/lisp/icomplete.el
+++ b/lisp/icomplete.el
@@ -69,7 +69,7 @@ When nil, show candidates in full."
   :version "24.4")
 
 (defvar icomplete-tidy-shadowed-file-names nil
-  "If non-nil, automatically delete superflous parts of file names.
+  "If non-nil, automatically delete superfluous parts of file names.
 For example, if the user types ~/ after a long path name,
 everything preceding the ~/ is discarded so the interactive
 selection process starts again from the user's $HOME.")
diff --git a/lisp/net/newst-backend.el b/lisp/net/newst-backend.el
index 9c24dec..792ddbb 100644
--- a/lisp/net/newst-backend.el
+++ b/lisp/net/newst-backend.el
@@ -1598,7 +1598,7 @@ This function calls `message' with arguments STRING and 
ARGS, if
 (defun newsticker--decode-iso8601-date (string)
   "Return ISO8601-STRING in format like `encode-time'.
 Converts from ISO-8601 to Emacs representation.  If no time zone
-is present, this fuction defaults to universal time."
+is present, this function defaults to universal time."
   (if string
       (condition-case nil
           (encode-time (decoded-time-set-defaults (iso8601-parse string) 0))
diff --git a/lisp/org/org-attach.el b/lisp/org/org-attach.el
index bc49be7..d3e1c78 100644
--- a/lisp/org/org-attach.el
+++ b/lisp/org/org-attach.el
@@ -187,7 +187,7 @@ attachment folders based on ID."
   "Hook that is invoked by `org-attach-open'.
 
 Created mostly to be compatible with org-attach-git after removing
-git-funtionality from this file.")
+git-functionality from this file.")
 
 (defcustom org-attach-commands
   '(((?a ?\C-a) org-attach-attach
@@ -231,7 +231,7 @@ directory in dired and delete from there.\n")
 Each entry in this list is a list of three elements:
 - A list of keys (characters) to select the command (the fist
   character in the list is shown in the attachment dispatcher's
-  splash buffer and minubuffer prompt).
+  splash buffer and minibuffer prompt).
 - A command that is called interactively when one of these keys
   is pressed.
 - A docstring for this command in the attachment dispatcher's
diff --git a/lisp/org/org.el b/lisp/org/org.el
index 11bc364..c289d54 100644
--- a/lisp/org/org.el
+++ b/lisp/org/org.el
@@ -9854,9 +9854,9 @@ Elements of length one have a tab appended.  Elements of 
length
 two are kept as is.  Longer elements are truncated to length two.
 
 If an element cannot be made unique, an error is raised."
-  (let ((orderd-keys (cl-sort (copy-sequence keys) #'< :key #'length))
+  (let ((ordered-keys (cl-sort (copy-sequence keys) #'< :key #'length))
        menu-keys)
-    (dolist (key orderd-keys)
+    (dolist (key ordered-keys)
       (let ((potential-key
             (cl-case (length key)
               (1 (concat key "\t"))
diff --git a/lisp/progmodes/cc-langs.el b/lisp/progmodes/cc-langs.el
index 44d0d49..da3fc6b 100644
--- a/lisp/progmodes/cc-langs.el
+++ b/lisp/progmodes/cc-langs.el
@@ -1416,7 +1416,7 @@ template opener followed by the \"::\" operator - 
usually."
               (c-lang-const c-<-pseudo-digraph-cont-regexp))
 
 (c-lang-defconst c-<-pseudo-digraph-cont-len
-  "The maximum length of the main bit of a `c-<pseudp-digraph-cont-regexp' 
match.
+  "The maximum length of the main bit of a `c-<-pseudo-digraph-cont-regexp' 
match.
 This doesn't count the merely contextual bits of the regexp match."
   t 0
   c++ 2)
diff --git a/lisp/progmodes/flymake.el b/lisp/progmodes/flymake.el
index f052e00..d980d67 100644
--- a/lisp/progmodes/flymake.el
+++ b/lisp/progmodes/flymake.el
@@ -708,7 +708,7 @@ backend is operating normally.")
   "Tell if Flymake has running backends in this buffer."
   (flymake-running-backends))
 
-;; FIXME: clone of `isearch-intesects-p'! Make this an util.
+;; FIXME: clone of `isearch-intersects-p'! Make this an util.
 (defun flymake--intersects-p (start0 end0 start1 end1)
   "Return t if regions START0..END0 and START1..END1 intersect."
   (or (and (>= start0 start1) (<  start0 end1))
diff --git a/lisp/progmodes/python.el b/lisp/progmodes/python.el
index 0eed7ac..b0d3174 100644
--- a/lisp/progmodes/python.el
+++ b/lisp/progmodes/python.el
@@ -3856,8 +3856,8 @@ Returns the tracked buffer."
 
 (defun python-pdbtrack-comint-input-filter-function (input)
   "Finish tracking session depending on command in INPUT.
-Commands that must finish tracking session is listed in
-`python-pdbtrack-untracking-commands'."
+Commands that must finish the tracking session are listed in
+`python-pdbtrack-exit-command'."
   (when (and python-pdbtrack-tracked-buffer
              ;; Empty input is sent by C-d or `comint-send-eof'
              (or (string-empty-p input)
diff --git a/lisp/subr.el b/lisp/subr.el
index ca5af0f..1b2a1d6 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -1572,7 +1572,7 @@ be a list of the form returned by `event-start' and 
`event-end'."
 ;; individual bytes at known offsets from the string beginning.
 ;; (make-obsolete 'string-to-unibyte   "use `encode-coding-string'." "26.1")
 ;; string-to-multibyte is also sometimes useful (and there's no good
-;; general replacement for it), so it's also been unobsoleted in Emacs 27.1.
+;; general replacement for it), so it's also been revived in Emacs 27.1.
 ;; (make-obsolete 'string-to-multibyte "use `decode-coding-string'." "26.1")
 ;; bug#23850
 (make-obsolete 'string-as-unibyte   "use `encode-coding-string'." "26.1")
diff --git a/lisp/thingatpt.el b/lisp/thingatpt.el
index 1ce4b98..c33fb17 100644
--- a/lisp/thingatpt.el
+++ b/lisp/thingatpt.el
@@ -634,7 +634,7 @@ Signal an error if the entire string was not used."
 (defun number-at-point ()
   "Return the number at point, or nil if none is found.
 Decimal numbers like \"14\" or \"-14.5\", as well as hex numbers
-like \"0xBEEF09\" or \"#xBEEF09\", are regognized."
+like \"0xBEEF09\" or \"#xBEEF09\", are recognized."
   (when (thing-at-point-looking-at
          "\\(-?[0-9]+\\.?[0-9]*\\)\\|\\(0x\\|#x\\)\\([a-zA-Z0-9]+\\)" 500)
     (if (match-beginning 1)
diff --git a/src/hbfont.c b/src/hbfont.c
index 5a057c2..2150b66 100644
--- a/src/hbfont.c
+++ b/src/hbfont.c
@@ -358,8 +358,8 @@ get_hb_unicode_funcs (void)
   hb_unicode_funcs_set_general_category_func (funcs, uni_general, NULL, NULL);
   hb_unicode_funcs_set_mirroring_func (funcs, uni_mirroring, NULL, NULL);
 
-  /* Use default implmentation for Unicode composition/decomposition, we might
-   * want to revisit this later.
+  /* Use default implementation for Unicode composition/decomposition.
+     We might want to revisit this later.
   hb_unicode_funcs_set_compose_func (funcs, uni_compose, NULL, NULL);
   hb_unicode_funcs_set_decompose_func (funcs, uni_decompose, NULL, NULL);
   */
@@ -379,7 +379,7 @@ get_hb_unicode_funcs (void)
    (N+1)th element of LGSTRING is nil, input of shaping is from the
    1st to (N)th elements.  In each input glyph, FROM, TO, CHAR, and
    CODE are already set, but FROM and TO need adjustments according
-   to the glyphs produced by the shaping fuinction.
+   to the glyphs produced by the shaping function.
    DIRECTION is either L2R or R2L, or nil if unknown.  During
    redisplay, this comes from applying the UBA, is passed from
    composition_reseat_it, and is used by the HarfBuzz shaper.
diff --git a/src/window.c b/src/window.c
index 1984a54..c52a8ca 100644
--- a/src/window.c
+++ b/src/window.c
@@ -7617,7 +7617,7 @@ set_window_fringes (struct window *w,
       else
        failed = true;
 
-      /* Placing fringes ouside margins.  */
+      /* Placing fringes outside margins.  */
       if (outside != w->fringes_outside_margins)
        {
          w->fringes_outside_margins = outside;
diff --git a/test/lisp/abbrev-tests.el b/test/lisp/abbrev-tests.el
index 2750e9a..8eee071 100644
--- a/test/lisp/abbrev-tests.el
+++ b/test/lisp/abbrev-tests.el
@@ -283,7 +283,7 @@
         (inverse-add-abbrev table "Global" 1)))
     (should (string= (abbrev-expansion "foo" table) "bar"))))
 
-(ert-deftest inverse-add-abbrev-skips-trailing-nonword/postiive-arg ()
+(ert-deftest inverse-add-abbrev-skips-trailing-nonword/positive-arg ()
   "Test that adding an inverse abbrev skips trailing nonword characters."
   (let ((table (make-abbrev-table)))
     (with-temp-buffer
diff --git a/test/lisp/cedet/semantic-utest-ia.el 
b/test/lisp/cedet/semantic-utest-ia.el
index 61d7ea3..5152755 100644
--- a/test/lisp/cedet/semantic-utest-ia.el
+++ b/test/lisp/cedet/semantic-utest-ia.el
@@ -115,7 +115,7 @@
     (should (file-exists-p tst))
     (should-not (semantic-ia-utest tst))))
 
-(ert-deftest semantic-utest-ia-varnamse.java ()
+(ert-deftest semantic-utest-ia-varnames.java ()
   (let ((tst (expand-file-name "testvarnames.java" 
semantic-utest-test-directory)))
     (should (file-exists-p tst))
     (should-not (semantic-ia-utest tst))))
diff --git a/test/lisp/cedet/srecode-utest-getset.el 
b/test/lisp/cedet/srecode-utest-getset.el
index d69a195..2e82fc9 100644
--- a/test/lisp/cedet/srecode-utest-getset.el
+++ b/test/lisp/cedet/srecode-utest-getset.el
@@ -21,7 +21,6 @@
 ;;
 ;; Unit tests for the getset inserter application.
 
-;;(require 'cedet-uutil)
 (require 'srecode/semantic)
 
 ;;; Code:
diff --git a/test/lisp/emacs-lisp/cl-macs-tests.el 
b/test/lisp/emacs-lisp/cl-macs-tests.el
index 8523044..d3b9732 100644
--- a/test/lisp/emacs-lisp/cl-macs-tests.el
+++ b/test/lisp/emacs-lisp/cl-macs-tests.el
@@ -569,14 +569,14 @@ collection clause."
                           finally return result)
                  '(2 1 0)))
 
-  ;; this nonintuitive result is replicated by clisp
+  ;; this unintuitive result is replicated by clisp
   (should (equal (cl-loop with result
                           for x below 3
                           and y = (progn (push x result))
                           finally return result)
                  '(2 1 0 0)))
 
-  ;; this nonintuitive result is replicated by clisp
+  ;; this unintuitive result is replicated by clisp
   (should (equal (cl-loop with result
                           for x below 3
                           and y = (progn (push x result)) then (progn (push 
(1+ x) result))
diff --git a/test/lisp/emacs-lisp/regexp-opt-tests.el 
b/test/lisp/emacs-lisp/regexp-opt-tests.el
index 3658964..6b94ccb 100644
--- a/test/lisp/emacs-lisp/regexp-opt-tests.el
+++ b/test/lisp/emacs-lisp/regexp-opt-tests.el
@@ -66,7 +66,7 @@
          (opt (regexp-opt-test--match-all perm opt-re)))
     (concat "\n"
             (format "Naïve regexp:     %s\n" ref-re)
-            (format "Optimised regexp: %s\n" opt-re)
+            (format "Optimized regexp: %s\n" opt-re)
             (format "Got:      %s\n" opt)
             (format "Expected: %s\n" ref))))
 
diff --git a/test/lisp/vc/log-edit-tests.el b/test/lisp/vc/log-edit-tests.el
index 7d77eca..72d5488 100644
--- a/test/lisp/vc/log-edit-tests.el
+++ b/test/lisp/vc/log-edit-tests.el
@@ -37,7 +37,7 @@
 \(fun6):
 \(fun7): Some prose.
 \(fun8): A longer description of a complicated change.\
-  Spread over a couple of sentencences.\
+  Spread over a couple of sentences.\
   Long enough to be filled for several lines.
 \(fun9): Etc.")
     (goto-char (point-min))
@@ -46,7 +46,7 @@
 * dir/file.ext (fun1, fun2, fun3):
 * file2.txt (fun4, fun5, fun6, fun7): Some prose.
 \(fun8): A longer description of a complicated change.  Spread over a
-couple of sentencences.  Long enough to be filled for several lines.
+couple of sentences.  Long enough to be filled for several lines.
 \(fun9): Etc."))
     (let ((fill-column 20)) (log-edit-fill-entry))
     (should (equal (buffer-string) "\
@@ -59,10 +59,9 @@ Some prose.
 description of a
 complicated change.
 Spread over a couple
-of sentencences.
-Long enough to be
-filled for several
-lines.
+of sentences.  Long
+enough to be filled
+for several lines.
 \(fun9): Etc."))
     (let ((fill-column 40)) (log-edit-fill-entry))
     (should (equal (buffer-string) "\
@@ -71,21 +70,21 @@ lines.
 Some prose.
 \(fun8): A longer description of a
 complicated change.  Spread over a
-couple of sentencences.  Long enough to
-be filled for several lines.
+couple of sentences.  Long enough to be
+filled for several lines.
 \(fun9): Etc."))))
 
 (ert-deftest log-edit-fill-entry-trailing-prose ()
   (with-temp-buffer
     (insert "\
 * dir/file.ext (fun1): A longer description of a complicated change.\
-  Spread over a couple of sentencences.\
+  Spread over a couple of sentences.\
   Long enough to be filled for several lines.")
     (let ((fill-column 72)) (log-edit-fill-entry))
     (should (equal (buffer-string) "\
 * dir/file.ext (fun1): A longer description of a complicated change.
-Spread over a couple of sentencences.  Long enough to be filled for
-several lines."))))
+Spread over a couple of sentences.  Long enough to be filled for several
+lines."))))
 
 (ert-deftest log-edit-fill-entry-joining ()
   ;; Join short enough function names on the same line.
diff --git a/test/manual/cedet/tests/test.srt b/test/manual/cedet/tests/test.srt
index b77cd4f..cbc8c3f 100644
--- a/test/manual/cedet/tests/test.srt
+++ b/test/manual/cedet/tests/test.srt
@@ -57,7 +57,7 @@ template testarea :blank
 ----
 
 ;; This is a bad hack - In order for the text to parse, but also get a 
completion
-;; monicker into the right spot, we need to pretend a comment is the same as 
the
+;; moniker into the right spot, we need to pretend a comment is the same as the
 ;; escape_end.
 ;; Local variables:
 ;; comment-start-skip: "}}"
diff --git a/test/manual/etags/cp-src/functions.cpp 
b/test/manual/etags/cp-src/functions.cpp
index 764498d..7c353d1 100644
--- a/test/manual/etags/cp-src/functions.cpp
+++ b/test/manual/etags/cp-src/functions.cpp
@@ -28,7 +28,7 @@ void Date::setDate ( int d , int m , int y ){
        t = mktime ( date ) ;
 }
 
-// Addition operation ::: Warning ::: A combination of addition and 
substraction does not give a proper result
+// Addition operation ::: Warning ::: A combination of addition and 
subtraction does not give a proper result
 void Date::plus ( int days , int month , int year ){
        if ( ! set () )
                return;
@@ -38,7 +38,7 @@ void Date::plus ( int days , int month , int year ){
        mktime ( date );
 }
 
-//Substraction operation ::: Warning ::: A combination of addition and 
substraction does not give a proper result
+//Subtraction operation ::: Warning ::: A combination of addition and 
subtraction does not give a proper result
 void Date::minus ( int days , int month , int year ){
        if ( ! set () )
                return;
@@ -74,7 +74,7 @@ Date & Date::operator += ( int days ){
        return(*this);
 }
 
-// Substract number of days
+// Subtract number of days
 Date & Date::operator -= ( int days ){
        if ( set () ){
                date->tm_mday -= days ;
diff --git a/test/src/buffer-tests.el b/test/src/buffer-tests.el
index 5fd3752..3a9b43e 100644
--- a/test/src/buffer-tests.el
+++ b/test/src/buffer-tests.el
@@ -565,7 +565,7 @@ with parameters from the *Messages* buffer modification."
 (deftest-previous-overlay-change-1 o 25 20 (30 30) (20 30))
 (deftest-previous-overlay-change-1 p 30 20 (20 20) (20 30))
 (deftest-previous-overlay-change-1 q 40 30 (20 20) (20 30))
-;; 1 empty, 1 non-empty, intersectig in the middle
+;; 1 empty, 1 non-empty, intersecting in the middle
 (deftest-previous-overlay-change-1 r 10 1 (25 25) (20 30))
 (deftest-previous-overlay-change-1 s 20 1 (25 25) (20 30))
 (deftest-previous-overlay-change-1 t 25 20 (25 25) (20 30))
@@ -969,7 +969,7 @@ with parameters from the *Messages* buffer modification."
       (should (= 25 (overlay-start right)))
       (should (= 75 (overlay-end right)))
       ;; Try to detect the error, by removing left.  The should fail
-      ;; an eassert, since it won't be found by a reular tree
+      ;; an eassert, since it won't be found by a regular tree
       ;; traversal - in theory.
       (delete-overlay left)
       (should (= 2 (length (overlays-in 1 (point-max))))))))
@@ -1045,7 +1045,7 @@ with parameters from the *Messages* buffer modification."
 ;; | make-indirect-buffer
 ;; +==========================================================================+
 
-;; Check if overlays are cloned/seperate from indirect buffer.
+;; Check if overlays are cloned/separate from indirect buffer.
 (ert-deftest test-make-indirect-buffer-1 ()
   (with-temp-buffer
     (dotimes (_ 10) (make-overlay 1 1))
diff --git a/test/src/fns-tests.el b/test/src/fns-tests.el
index 93f7f63..bcc652a 100644
--- a/test/src/fns-tests.el
+++ b/test/src/fns-tests.el
@@ -269,7 +269,7 @@
   (should (equal (base64-encode-string "\x14\xfb\x9c\x03\xd9\x7f") 
"FPucA9l/")))
 
 (ert-deftest fns-test-base64url-encode-region ()
-  ;; url variant wih padding
+  ;; url variant with padding
   (should (equal (fns-tests--with-region base64url-encode-region "") ""))
   (should (equal (fns-tests--with-region base64url-encode-region "f") "Zg=="))
   (should (equal (fns-tests--with-region base64url-encode-region "fo") "Zm8="))
@@ -311,7 +311,7 @@
                  (fns-tests--string-repeat "FPucA9l_" 10))))
 
 (ert-deftest fns-test-base64url-encode-string ()
-  ;; url variant wih padding
+  ;; url variant with padding
   (should (equal (base64url-encode-string "") ""))
   (should (equal (base64url-encode-string "f") "Zg=="))
   (should (equal (base64url-encode-string "fo") "Zm8="))
@@ -356,7 +356,7 @@
   (should (equal (base64-decode-string "FPucA9l+") "\x14\xfb\x9c\x03\xd9\x7e"))
   (should (equal (base64-decode-string "FPucA9l/") "\x14\xfb\x9c\x03\xd9\x7f"))
 
-  ;; no paddign
+  ;; no padding
   (should (equal (base64-decode-string "" t) ""))
   (should (equal (base64-decode-string "Zg" t) "f"))
   (should (equal (base64-decode-string "Zm8" t) "fo"))
@@ -365,7 +365,7 @@
   (should (equal (base64-decode-string "Zm9vYmE" t) "fooba"))
   (should (equal (base64-decode-string "Zm9vYmFy" t) "foobar"))
 
-  ;; url variant wih padding
+  ;; url variant with padding
   (should (equal (base64-decode-string "") ""))
   (should (equal (base64-decode-string "Zg==" t) "f") )
   (should (equal (base64-decode-string "Zm8=" t) "fo"))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/hideshow.el b/lisp/progmodes/hideshow.el
index 53235ea..8f8b79a 100644
--- a/lisp/progmodes/hideshow.el
+++ b/lisp/progmodes/hideshow.el
@@ -610,7 +610,7 @@ as cdr."
         (forward-comment (- (buffer-size)))
         (skip-chars-forward " \t\n\f")
         (let ((p (point))
-              (hidable t))
+              (hideable t))
           (beginning-of-line)
           (unless (looking-at (concat "[ \t]*" hs-c-start-regexp))
             ;; we are in this situation: (example)
@@ -636,13 +636,13 @@ as cdr."
             (when (or (not (looking-at hs-c-start-regexp))
                       (> (point) q))
               ;; we cannot hide this comment block
-              (setq hidable nil)))
+              (setq hideable nil)))
           ;; goto the end of the comment
           (forward-comment (buffer-size))
           (skip-chars-backward " \t\n\f")
           (end-of-line)
           (when (>= (point) q)
-            (list (and hidable p) (point))))))))
+            (list (and hideable p) (point))))))))
 
 (defun hs-grok-mode-type ()
   "Set up hideshow variables for new buffers.
@@ -741,7 +741,7 @@ and `case-fold-search' are both t."
   (save-excursion
     (let ((c-reg (hs-inside-comment-p)))
       (if (and c-reg (nth 0 c-reg))
           ;; point is inside a comment, and that comment is hidable
           (goto-char (nth 0 c-reg))
         (end-of-line)
         (when (and (not c-reg)
@@ -741,7 +741,7 @@ and `case-fold-search' are both t."
     (let ((c-reg (hs-inside-comment-p)))
       (if (and c-reg (nth 0 c-reg))
-          ;; point is inside a comment, and that comment is hidable
+          ;; point is inside a comment, and that comment is hideable
           (goto-char (nth 0 c-reg))
         (end-of-line)
diff --git a/lisp/so-long.el b/lisp/so-long.el
index 3df2de9..160a945 100644
--- a/lisp/so-long.el
+++ b/lisp/so-long.el
@@ -69,7 +69,7 @@
 ;; the long lines.  In such circumstances you may find that `longlines-mode' is
 ;; the most helpful facility.
 ;;
 ;; Note also that the mitigations are automatically triggered when visiting a
 ;; file.  The library does not automatically detect if long lines are inserted
 ;; into an existing buffer (although the `so-long' command can be invoked
 ;; manually in such situations).
@@ -386,7 +386,7 @@
 ;;       - Added sgml-mode and nxml-mode to `so-long-target-modes'.
 ;; 0.7.4 - Refactored the handling of `whitespace-mode'.
 ;; 0.7.3 - Added customize group `so-long' with user options.
-;;       - Added `so-long-original-values' to generalise the storage and
+;;       - Added `so-long-original-values' to generalize the storage and
 ;;         restoration of values from the original mode upon `so-long-revert'.
 ;;       - Added `so-long-revert-hook'.
 ;; 0.7.2 - Remember the original major mode even with M-x `so-long-mode'.
@@ -421,7 +421,7 @@
 Has no effect if `global-so-long-mode' is not enabled.")
 
 (defvar-local so-long--active nil ; internal use
-  "Non-nil when `so-long' mitigations are in effect.")
+  "Non-nil when `so-long' mitigation is in effect.")
 
 (defvar so-long--set-auto-mode nil ; internal use
   "Non-nil while `set-auto-mode' is executing.")
@@ -740,7 +740,7 @@ was established."
     )
   ;; It's not clear to me whether all of these would be problematic, but they
   ;; seemed like reasonable targets.  Some are certainly excessive in smaller
-  ;; buffers of minified code, but we should be aiming to maximise performance
+  ;; buffers of minified code, but we should be aiming to maximize performance
   ;; by default, so that Emacs is as responsive as we can manage in even very
   ;; large buffers of minified code.
   "List of buffer-local minor modes to explicitly disable.
@@ -781,7 +781,7 @@ If `so-long-revert' is subsequently invoked, then the 
variables are restored
 to their original states.
 
 The combination of `line-move-visual' (enabled) and `truncate-lines' (disabled)
-is important for maximising responsiveness when moving vertically within an
+is important for maximizing responsiveness when moving vertically within an
 extremely long line, as otherwise the full length of the line may need to be
 scanned to find the next position."
   :type '(alist :key-type (variable :tag "Variable")
@@ -822,12 +822,12 @@ If nil, no mode line indicator will be displayed."
 
 (defface so-long-mode-line-active
   '((t :inherit mode-line-emphasis))
-  "Face for `so-long-mode-line-info' when mitigations are active."
+  "Face for `so-long-mode-line-info' when mitigation is active."
   :package-version '(so-long . "1.0"))
 
 (defface so-long-mode-line-inactive
   '((t :inherit mode-line-inactive))
-  "Face for `so-long-mode-line-info' when mitigations have been reverted."
+  "Face for `so-long-mode-line-info' when mitigation has been reverted."
   :package-version '(so-long . "1.0"))
 
 ;; Modes that go slowly and line lengths excessive
@@ -983,7 +983,7 @@ Displayed as part of `mode-line-misc-info'.
 
 `so-long-mode-line-label' defines the text to be displayed (if any).
 
-Face `so-long-mode-line-active' is used while mitigations are active, and
+Face `so-long-mode-line-active' is used while mitigation is active, and
 `so-long-mode-line-inactive' is used if `so-long-revert' is called.
 
 Not displayed when `so-long-mode' is enabled, as the major mode construct
@@ -1659,7 +1659,7 @@ Equivalent to calling (global-so-long-mode 0)"
 
 ;;;###autoload
 (define-minor-mode global-so-long-mode
-  "Toggle automated performance mitigations for files with long lines.
+  "Toggle automated performance mitigation for files with long lines.
 
 Many Emacs modes struggle with buffers which contain excessively long lines,
 and may consequently cause unacceptable performance issues.
@@ -1861,11 +1861,11 @@ If it appears in `%s', you should remove it."
 ; LocalWords:  initialized profiler boolean minified pre redisplay config 
keymap
 ; LocalWords:  noerror selectable mapc sgml nxml hl flydiff defs arg Phil 
Sainty
 ; LocalWords:  defadvice nadvice whitespace ie bos eos eobp origmode un Un setq
-; LocalWords:  docstring auf wiedersehen longlines alist autoload Refactored 
Inc
-; LocalWords:  MERCHANTABILITY RET REGEXP VAR ELPA WS mitigations EmacsWiki 
eval
+; LocalWords:  docstring auf Wiedersehen longlines alist autoload Refactored 
Inc
+; LocalWords:  MERCHANTABILITY RET REGEXP VAR ELPA WS EmacsWiki eval
 ; LocalWords:  rx filename filenames
 
-;; So long, farewell, auf wiedersehen, goodbye
+;; So long, farewell, auf Wiedersehen, goodbye
 ;; You have to go, this code is minified
 ;; Goodbye!
 
@@ -69,7 +69,7 @@
 ;; the most helpful facility.
 ;;
-;; Note also that the mitigations are automatically triggered when visiting a
+;; Note also that the mitigation is automatically triggered when visiting a
 ;; file.  The library does not automatically detect if long lines are inserted
 ;; into an existing buffer (although the `so-long' command can be invoked
diff --git a/src/xdisp.c b/src/xdisp.c
index 2467b33..08c6927 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -21693,7 +21693,7 @@ extend_face_to_end_of_line (struct it *it)
              && indicator_column < it->last_visible_x)
            {
 
              /* Here we substract char_width because we want the
                 column indicator in the column INDICATOR_COLUMN,
                 not after it.  */
              const int stretch_width =
@@ -21865,7 +21865,7 @@ extend_face_to_end_of_line (struct it *it)
       /* We need to subtract 1 to the indicator_column here because we
         will add the indicator IN the column indicator number, not
         after it.  We compare the variable it->current_x before
-        producing the glyph.  When FRAME_WINDOW_P we substract
+        producing the glyph.  When FRAME_WINDOW_P we subtract
         CHAR_WIDTH calculating STRETCH_WIDTH for the same reason.  */
       const int indicator_column =
        fill_column_indicator_column (it, 1) - 1;
@@ -21693,7 +21693,7 @@ extend_face_to_end_of_line (struct it *it)
            {
 
-             /* Here we substract char_width because we want the
+             /* Here we subtract char_width because we want the
                 column indicator in the column INDICATOR_COLUMN,
                 not after it.  */
diff --git a/test/manual/cedet/tests/test-fmt.cpp 
b/test/manual/cedet/tests/test-fmt.cpp
index c94bcfa..6ae373d 100644
--- a/test/manual/cedet/tests/test-fmt.cpp
+++ b/test/manual/cedet/tests/test-fmt.cpp
@@ -56,12 +56,12 @@ struct moose {
  * ## uml-prototype "moose{} : struct"
  */
 
-struct moose strct_fcn ( struct moose in, char *out);
+struct moose struct_fcn ( struct moose in, char *out);
 /*
  * ## name "strct_fcn"
  * ## abbreviate "strct_fcn()"
  * ## prototype "struct moose strct_fcn (struct moose in,char* out)"
  * ## uml-prototype "strct_fcn (in : struct moose,out : char*) : struct moose"
  */
 
 struct moose *var_one = NULL;
@@ -56,12 +56,12 @@ struct moose {
 /*
- * ## name "strct_fcn"
- * ## abbreviate "strct_fcn()"
- * ## prototype "struct moose strct_fcn (struct moose in,char* out)"
- * ## uml-prototype "strct_fcn (in : struct moose,out : char*) : struct moose"
+ * ## name "struct_fcn"
+ * ## abbreviate "struct_fcn()"
+ * ## prototype "struct moose struct_fcn (struct moose in,char* out)"
+ * ## uml-prototype "struct_fcn (in : struct moose,out : char*) : struct moose"
  */
 